@@ -44,6 +44,7 @@ def test_unicode_surrogate():
 @given(binary())
 @example(b'\x9f')
 @example(b'\xfe\xff')
+@example(b'\xff\xfe')
 def test_codec_involution(b):
     # For most binary strings, there is a pdfdoc decoding and the encoding of that
     # decoding recovers the initial string.
@@ -55,7 +56,7 @@ def test_codec_involution(b):
         assert set(e.object[e.start : e.end]) & set(b'\x7f\x9f\xad')
     except UnicodeEncodeError as e:
         assert "'pdfdoc' codec can't encode characters in position 0-1" in str(e)
-        assert b.startswith(b'\xfe\xff')
+        assert b.startswith(b'\xfe\xff') or b.startswith(b'\xff\xfe')
 
 
 @given(text())
